KitPyLib
========

A Python Toolkit Library for developing packages.

How to install this package
---------------------------
If you don’t have Python yet and want the simplest way to get started, 
we recommend you use the Anaconda Distribution, or using::

  pip install kitpylib

How to use documentation
------------------------
We recommend you to import `kitpylib` as ``kpl``::

  >>> import kitpylib as kpl
  >>> kpl.fplot2d(lambda x: x**3, 0, 2)
  
Use the built-in ``help`` function to view a function's docstring::

  >>> help(kpl.fplot2d)
  ... # doctest: +SKIP

You can also visit our website https://kitpylib.pages.dev for more information.
